#
# spec file for package vhostmd
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define with_xen        0%{!?_without_xen:1}

# Xen is available only on x86_64
%ifnarch x86_64
%define with_xen        0
%endif

Name:           vhostmd
Version:        1.1
Release:        lp150.7.1
Summary:        Virtual Host Metrics Daemon (vhostmd)
License:        LGPL-2.1+
Group:          System/Daemons
Url:            https://github.com/vhostmd/vhostmd
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source0:        vhostmd-%{version}.tar.bz2
Patch0:         vhostmd-conf.patch
Patch1:         manpage.patch
Patch2:         value-newline.patch
Patch3:         libmetrics-link.patch
BuildRequires:  libtool
BuildRequires:  libvirt-devel
BuildRequires:  libxml2
BuildRequires:  libxml2-devel
BuildRequires:  pkg-config
BuildRequires:  systemd
%{?systemd_requires}
%if %{with_xen}
BuildRequires:  xen-devel
%endif
PreReq:         coreutils

%description
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines.

%package -n     vm-dump-metrics
Summary:        Virtual Host Metrics Daemon (vhostmd)
Group:          System/Monitoring

%description -n vm-dump-metrics
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines.

%package -n     libmetrics0
Summary:        Virtual Host Metrics Daemon (vhostmd)
Group:          System/Libraries

%description -n libmetrics0
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines.

%package -n     libmetrics-devel
Summary:        Virtual Host Metrics Daemon (vhostmd)
Group:          Development/Libraries/C and C++
Requires:       libmetrics0 = %{version}

%description -n libmetrics-devel
vhostmd provides a "metrics communication channel" between a host and
its hosted virtual machines, allowing limited introspection of host
resource usage from within virtual machines.

%prep
%setup
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
%if ! %{with_xen}
%define _disable_libxenstat --disable-libxenstat
%define _disable_xenctrl --disable-xenctrl
%endif

autoreconf -fi
%configure --without-xenstore \
     %{?_disable_libxenstat}  \
     %{?_disable_xenctrl}
make

%install
%make_install
rm -f %{buildroot}/%{_libdir}/*.la %{buildroot}/%{_libdir}/*.a
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcvhostmd

%pre
%service_add_pre vhostmd.service

%post
%service_add_post vhostmd.service

%preun
%service_del_preun vhostmd.service

%postun
%service_del_postun vhostmd.service

%post   -n libmetrics0 -p /sbin/ldconfig
%postun -n libmetrics0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir /etc/vhostmd
%dir %{_datadir}/vhostmd
%dir %{_datadir}/vhostmd/scripts
%dir %{_datadir}/doc/vhostmd
%{_sbindir}/vhostmd
%{_sbindir}/rcvhostmd
%{_datadir}/vhostmd/scripts/pagerate.pl
%config(noreplace) /etc/vhostmd/vhostmd.conf
%config /etc/vhostmd/vhostmd.dtd
%config /etc/vhostmd/metric.dtd
%{_unitdir}/vhostmd.service
%{_datadir}/doc/vhostmd/vhostmd.dtd
%{_datadir}/doc/vhostmd/metric.dtd
%{_datadir}/doc/vhostmd/vhostmd.xml
%{_datadir}/doc/vhostmd/mdisk.xml
%{_datadir}/doc/vhostmd/README
%{_datadir}/man/man8/vhostmd.8.gz

%files -n vm-dump-metrics
%defattr(-,root,root)
%{_sbindir}/vm-dump-metrics
%{_datadir}/man/man1/vm-dump-metrics.1.gz

%files -n libmetrics0
%defattr(-,root,root)
%{_libdir}/libmetrics.so.*

%files -n libmetrics-devel
%defattr(-,root,root)
%{_libdir}/libmetrics.so
%dir %{_includedir}/vhostmd
%{_includedir}/vhostmd/libmetrics.h

%changelog
* Fri Apr 12 2019 James Fehlig <jfehlig@suse.com>
- Update to vhostmd 1.1
  - Merge libserialclient with libmetrics
  - Add virtio as transport mechanism
  - Update to work with modern Xen
  - Add SIGPIPE handler and reconnect
  - Add systemd service file
  - Modernize build files
  - Misc bug fixes and improvements
  - Dropped patches:
    modernize-build-files.patch,
    add-systemd-service.patch,
    c7646e32-handle-sigpipe-reconnect.patch,
    03dc9982-fix-deallocation.patch
  - bsc#1129772
* Mon Jun 25 2018 jfehlig@suse.com
- Handle SIGPIPE and reconnect to libvirtd
  c7646e32-handle-sigpipe-reconnect.patch,
  03dc9982-fix-deallocation.patch
  bsc#1098804
* Mon Apr 30 2018 jfehlig@suse.com
- vhostmd.service: fix typo and move Documentation from [Service]
  to [Unit] section (changed add-systemd-service.patch)
  bsc#1090769
* Sat Apr 29 2017 jengelh@inai.de
- Fix RPM group for libmetrics0
- Replace old RPM shell vars in %%install
- Author lists do not belong into the description
- Use macros in file list to compact paths
* Thu Apr 27 2017 jfehlig@suse.com
- Add systemd service file
  add-systemd-service.patch
  bsc#1036427
- Replace build-improvements.patch with
  modernize-build-files.patch sent upstream
* Wed Jan 14 2015 jfehlig@suse.com
- Build vhostmd for all architectures
* Tue Nov 11 2014 jfehlig@suse.com
- Improve build scripts
  Replace build-fix.patch with build-improvements.patch
* Mon Nov  3 2014 jfehlig@suse.com
- Fix Factory build
  build-fix.patch
* Fri Jun 13 2014 mlatimer@suse.com
- Further updates to vmhostd.xml
  - Support both xen and non-xen hypervisors (kvm)
  - Document reserved characters in 'action' field
  - Revert xen_version back to major/minor/extra to maintain compatability
    with xend
  - Minor syntax and legibility cleanup
  vhostmd-conf.patch
  bnc#872736
* Wed Jun 11 2014 mlatimer@suse.com
- Various updates to vmhostd.xml
  - Replace xm commands with xl commands
  - Add /sbin and /bin to <path>
  - Use xen_version for VirtualizationProductInfo
  vhostmd-conf.patch
* Tue Dec 10 2013 jfehlig@suse.com
- link libmetrics with libxml to fix Factory build
* Sun Nov 20 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Tue Mar 30 2010 jfehlig@novell.com
- Fixed vm-dump-metrics man page
  bnc#592242
  manpage.patch
- Build vhostmd without xenstore support since it is not well
  tested on SuSE distributions.  Additionally, it can be confusing
  when used in context of KVM where xenstore does not exist.
- Strip 's' (seconds) from metrics that contain a time value
  vhostmd-conf.patch
- Remove stray newline from metric values to improve XML readability
  value-newline.patch
* Wed Dec  9 2009 jfehlig@novell.com
- Release of version 0.4
  - configure.ac: Fix C compiler detection to be compatible with
    automake
  - chdir ("/") when daemonizing self
* Fri Oct 30 2009 jfehlig@novell.com
- Release of version 0.3
  - change default disk location to /dev/shm/vhostmd0
  - open metrics disk with O_DIRECT
  - Fixes for '--with{,out}-xenstore' option
  - Allow gcc to check calls to vu_log* printf-like functions
  - Always connect to libvirt read-only
  - Add '-u user' command line option to drop root privs
  - Add '-c uri' command line option to specify libvirt connection
    URI
  - Add CONNECT substitution <action>s
  - vm-dump-metrics: On error, exit with status code 1
* Tue Sep 29 2009 aj@suse.de
- Fix devel package requires.
* Wed Sep 16 2009 dmueller@suse.de
- fix devel package requires
* Mon Jun 29 2009 jfehlig@novell.com
- Validate XML returned by 'action' for metric type 'xml'
- Do not convert metrics values internally in vhostmd.  Treat
  all metric values as strings and leave it to consumers to do
  any conversion.
* Fri Jun 26 2009 jfehlig@novell.com
- Allow larger buffer for 'xml' type
* Fri Jun 26 2009 jfehlig@novell.com
- Add metric type 'XML'
* Fri Jun 19 2009 jfehlig@novell.com
- vhostmd is currently only used with Xen so make it
  ExclusiveArch x86 and x86_64
* Mon Jun 15 2009 jfehlig@novell.com
- Truncate metrics disk on open
* Tue Jun  9 2009 jfehlig@novell.com
- Change COPYING from GPL3 to LGPL2.1
* Fri Jun  5 2009 jfehlig@novell.com
- Explicitly name subpackages with -n
* Fri Jun  5 2009 jfehlig@novell.com
- Version 0.2
  - Updated documentation
  - Added group metric type
  - Added perl script for generating {PageIn,PageFault}Rate
* Wed Jan  7 2009 plc@novell.com
- Initial creation
